@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::GenPericmdScript;
 
-our $DATE = '2017-07-07'; # DATE
-our $VERSION = '0.41'; # VERSION
+our $DATE = '2017-08-12'; # DATE
+our $VERSION = '0.420'; # VERSION
 
 use 5.010001;
 use strict;
@@ -53,6 +53,8 @@ has per_arg_json => (is=>'rw');
 has per_arg_yaml => (is=>'rw');
 has validate_args => (is=>'rw');
 has pack_deps => (is=>'rw');
+has read_config => (is=>'rw');
+has read_env => (is=>'rw');
 
 has inline_generate_completer => (is=>'rw', default=>1);
 
@@ -167,6 +169,8 @@ sub munge_files {
             (validate_args => $self->validate_args) x !!defined($self->validate_args),
             (pack_deps => $self->pack_deps) x !!defined($self->pack_deps),
             pod => 0, # will be generated by PWP:Rinci
+            (read_config => $self->read_config) x !!defined($self->read_config),
+            (read_env => $self->read_env) x !!defined($self->read_env),
         );
         #use DD; dd \%gen_args;
         $res = gen_pericmd_script(%gen_args);
@@ -258,7 +262,7 @@ Dist::Zilla::Plugin::GenPericmdScript - Generate Perinci::CmdLine script
 
 =head1 VERSION
 
-This document describes version 0.41 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2017-07-07.
+This document describes version 0.420 of Dist::Zilla::Plugin::GenPericmdScript (from Perl distribution Dist-Zilla-Plugin-GenPericmdScript), released on 2017-08-12.
 
 =head1 SYNOPSIS
 
@@ -438,6 +442,14 @@ Will be passed to Perinci::CmdLine::Gen backend.
 
 Will be passed to Perinci::CmdLine::Gen backend.
 
+=head2 read_config => bool
+
+Will be passed to Perinci::CmdLine::Gen backend.
+
+=head2 read_env => bool
+
+Will be passed to Perinci::CmdLine::Gen backend.
+
 =head1 CONFIGURATION (OTHER)
 
 =head2 inline_generate_completer => bool (default: 1)
